@@ -3,5 +3,6 @@ name = "pycromanager"
 from pycromanager.acquisitions import Acquisition, MagellanAcquisition, XYTiledAcquisition
 from pycromanager.acq_util import start_headless, multi_d_acquisition_events
 from ndtiff import Dataset
-from pycromanager.mm_java_classes import *
+from pycromanager.mm_java_classes import Studio, Magellan, Core
+from pycromanager.zmq_bridge.wrappers import JavaObject, JavaClass, PullSocket, PushSocket
 from ._version import __version__, version_info
